==> flexible-process-springboot-1.3.0.Final-sources.jar: org/kie/kogito/handlers/TriageService_assignEngineer_10_Handler.java <==
package org.kie.kogito.handlers;

import org.kie.kogito.process.workitem.WorkItemExecutionError;

@org.springframework.stereotype.Component()
public class TriageService_assignEngineer_10_Handler implements org.kie.kogito.internal.process.runtime.KogitoWorkItemHandler {

    org.kie.flexible.kogito.example.service.TriageService service;

    public TriageService_assignEngineer_10_Handler() {
        this(new org.kie.flexible.kogito.example.service.TriageService());
    }

    @org.springframework.beans.factory.annotation.Autowired()
    @org.springframework.context.annotation.Lazy()
    public TriageService_assignEngineer_10_Handler(org.kie.flexible.kogito.example.service.TriageService service) {
        this.service = service;
    }

    public void executeWorkItem(org.kie.kogito.internal.process.runtime.KogitoWorkItem workItem, org.kie.kogito.internal.process.runtime.KogitoWorkItemManager workItemManager) {
        java.lang.Object result;
        result = service.assignEngineer((org.kie.flexible.kogito.example.model.SupportCase) workItem.getParameter("supportCase"), (String) workItem.getParameter("supportGroup"));
        workItemManager.completeWorkItem(workItem.getStringId(), java.util.Collections.singletonMap("supportCase", result));
    }

    public void abortWorkItem(org.kie.kogito.internal.process.runtime.KogitoWorkItem workItem, org.kie.kogito.internal.process.runtime.KogitoWorkItemManager workItemManager) {
    }

    public String getName() {
        return "org.kie.flexible.kogito.example.service.TriageService_assignEngineer_10_Handler";
    }
}

==> flexible-process-springboot-1.4.1.Final-sources.jar: org/kie/kogito/handlers/TriageService_assignEngineer_10_Handler.java <==
package org.kie.kogito.handlers;

import org.kie.kogito.process.workitem.WorkItemExecutionException;

@org.springframework.stereotype.Component()
public class TriageService_assignEngineer_10_Handler implements org.kie.kogito.internal.process.runtime.KogitoWorkItemHandler {

    org.kie.flexible.kogito.example.service.TriageService service;

    public TriageService_assignEngineer_10_Handler() {
        this(new org.kie.flexible.kogito.example.service.TriageService());
    }

    @org.springframework.beans.factory.annotation.Autowired()
    @org.springframework.context.annotation.Lazy()
    public TriageService_assignEngineer_10_Handler(org.kie.flexible.kogito.example.service.TriageService service) {
        this.service = service;
    }

    public void executeWorkItem(org.kie.kogito.internal.process.runtime.KogitoWorkItem workItem, org.kie.kogito.internal.process.runtime.KogitoWorkItemManager workItemManager) {
        java.lang.Object result;
        result = service.assignEngineer((org.kie.flexible.kogito.example.model.SupportCase) workItem.getParameter("supportCase"), (String) workItem.getParameter("supportGroup"));
        workItemManager.completeWorkItem(workItem.getStringId(), java.util.Collections.singletonMap("supportCase", result));
    }

    public void abortWorkItem(org.kie.kogito.internal.process.runtime.KogitoWorkItem workItem, org.kie.kogito.internal.process.runtime.KogitoWorkItemManager workItemManager) {
    }

    public String getName() {
        return "org.kie.flexible.kogito.example.service.TriageService_assignEngineer_10_Handler";
    }
}
